@@ -30,8 +30,22 @@
 #define EXPORT
 #endif
 
+#ifdef __GNUG__
+#define GCC_VERSION \
+    (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
+#if GCC_VERSION < 40800  // https://gcc.gnu.org/bugzilla/show_bug.cgi?id=54249
+namespace std {
+    typedef decltype(nullptr) nullptr_t;
+}
+#endif
+#endif
+
 #include <Python.h>
 
+#if !defined(PYPY_VERSION) && defined(PYPY_VERSION_NUM)
+#define PYPY_VERSION
+#endif
+
 #if PY_VERSION_HEX < 0x02040000
 #define Py_RETURN_NONE return Py_INCREF(Py_None), Py_None
 #define Py_RETURN_TRUE return Py_INCREF(Py_True), Py_True
@@ -83,16 +97,25 @@ typedef intintobjargproc ssizessizeobjargproc;
 # endif
 #endif
 
+/* apparently a macro defined by some versions of the MSVC compiler */
+#ifdef daylight
+#undef daylight
+#endif
+
 #include <unicode/utypes.h>
 #include <unicode/unistr.h>
 #include <unicode/ucnv.h>
 #include <unicode/locid.h>
+#include <unicode/uloc.h>
 #include <unicode/resbund.h>
 #include <unicode/calendar.h>
 #include <unicode/gregocal.h>
 #include <unicode/format.h>
 #include <unicode/datefmt.h>
 #include <unicode/smpdtfmt.h>
+#include <unicode/udat.h>
+#include <unicode/udatpg.h>
+#include <unicode/dtptngen.h>
 #include <unicode/measfmt.h>
 #include <unicode/msgfmt.h>
 #include <unicode/numfmt.h>
@@ -240,6 +263,7 @@ private:
     PyObject *msg;
 public:
     EXPORT ICUException();
+    EXPORT ICUException(const ICUException &e);
     EXPORT ICUException(UErrorCode status);
     EXPORT ICUException(UErrorCode status, char *format, ...);
     EXPORT ICUException(UParseError &pe, UErrorCode status);
@@ -247,7 +271,7 @@ public:
     EXPORT PyObject *reportError();
 };
 
-EXPORT PyObject *PyUnicode_FromUnicodeString(UnicodeString *string);
+EXPORT PyObject *PyUnicode_FromUnicodeString(const UnicodeString *string);
 EXPORT PyObject *PyUnicode_FromUnicodeString(const UChar *chars, int size);
 
 EXPORT UnicodeString &PyBytes_AsUnicodeString(PyObject *object,
@@ -343,7 +367,7 @@ int _parseArgs(PyObject **args, int count, const char *types, va_list list);
 
 #define parseArgs(args, types, rest...) \
     _parseArgs(((PyTupleObject *)(args))->ob_item, \
-               PyObject_Size(args), types, ##rest)
+               (int) PyObject_Size(args), types, ##rest)
 
 #define parseArg(arg, types, rest...) \
     _parseArgs(&(arg), 1, types, ##rest)
