@@ -7,10 +7,10 @@
 # to deal in the Software without restriction, including without limitation
 # the rights to use, copy, modify, merge, publish, distribute, sublicense,
 # and/or sell copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following conditions: 
+# Software is furnished to do so, subject to the following conditions:
 #
 # The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software. 
+# in all copies or substantial portions of the Software.
 #
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 # OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -30,6 +30,12 @@ from icu import *
 
 class TestNormalizer2(TestCase):
 
+    def assertNorm(self, normalizer2, expected, source):
+        self.assertEquals(expected, normalizer2.normalize(source))
+        a = UnicodeString()
+        normalizer2.normalize(source, a)
+        self.assertEquals(UnicodeString(expected), a)
+
     def testNormalize(self):
 
         try:
@@ -37,15 +43,20 @@ class TestNormalizer2(TestCase):
         except ImportError:
             return
 
-        normalizer = Normalizer2.getInstance(None, "nfkc_cf",
-                                             UNormalizationMode2.COMPOSE)
+        self.assertNorm(Normalizer2.getInstance(None, "nfkc_cf",
+                                                UNormalizationMode2.COMPOSE),
+                        u'hi there', "Hi There")
+        self.assertNorm(Normalizer2.getNFCInstance(),
+                        u"äßáＷ", u"äßa\u0301Ｗ")
+        self.assertNorm(Normalizer2.getNFDInstance(),
+                        u"a\u0308ßa\u0301Ｗ", u"äßa\u0301Ｗ")
+        self.assertNorm(Normalizer2.getNFKCInstance(),
+                        u"äßáW", u"äßa\u0301Ｗ")
+        self.assertNorm(Normalizer2.getNFKDInstance(),
+                        u"a\u0308ßa\u0301W", u"äßa\u0301Ｗ")
+        self.assertNorm(Normalizer2.getNFKCCasefoldInstance(),
+                        u"ässáw", u"äßa\u0301Ｗ")
 
-        self.assertTrue(normalizer.normalize("Hi There") == u'hi there')
-
-        a = UnicodeString()
-        normalizer.normalize("Hi There", a)
-        self.assertTrue(a == UnicodeString(u'hi there'))
-        
 
 if __name__ == "__main__":
     main()
