@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2010-2010 Open Source Applications Foundation.
+ * Copyright (c) 2010-2015 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -29,7 +29,6 @@
 #include "macros.h"
 
 DECLARE_CONSTANTS_TYPE(UMatchDegree);
-DECLARE_CONSTANTS_TYPE(UProperty);
 DECLARE_CONSTANTS_TYPE(USetSpanCondition);
 
 
@@ -1186,7 +1185,7 @@ static PyObject *t_unicodeset_richcmp(t_unicodeset *self, PyObject *arg, int op)
 
 static PyObject *t_unicodeset_iter(t_unicodeset *self)
 {
-    return PyObject_CallFunctionObjArgs((PyObject *) &UnicodeSetIteratorType,
+    return PyObject_CallFunctionObjArgs((PyObject *) &UnicodeSetIteratorType_,
                                         (PyObject *) self, NULL);
 }
 
@@ -1371,18 +1370,17 @@ static PyObject *t_unicodesetiterator_iter_next(t_unicodesetiterator *self)
 
 void _init_unicodeset(PyObject *m)
 {
-    UnicodeSetType.tp_str = (reprfunc) t_unicodeset_str;
-    UnicodeSetType.tp_richcompare = (richcmpfunc) t_unicodeset_richcmp;
-    UnicodeSetType.tp_hash = (hashfunc) t_unicodeset_hash;
-    UnicodeSetType.tp_iter = (getiterfunc) t_unicodeset_iter;
-    UnicodeSetType.tp_as_sequence = &t_unicodeset_as_sequence;
-    UnicodeSetIteratorType.tp_iter =
+    UnicodeSetType_.tp_str = (reprfunc) t_unicodeset_str;
+    UnicodeSetType_.tp_richcompare = (richcmpfunc) t_unicodeset_richcmp;
+    UnicodeSetType_.tp_hash = (hashfunc) t_unicodeset_hash;
+    UnicodeSetType_.tp_iter = (getiterfunc) t_unicodeset_iter;
+    UnicodeSetType_.tp_as_sequence = &t_unicodeset_as_sequence;
+    UnicodeSetIteratorType_.tp_iter =
         (getiterfunc) t_unicodesetiterator_iter;
-    UnicodeSetIteratorType.tp_iternext =
+    UnicodeSetIteratorType_.tp_iternext =
         (iternextfunc) t_unicodesetiterator_iter_next;
 
     INSTALL_CONSTANTS_TYPE(UMatchDegree, m);
-    INSTALL_CONSTANTS_TYPE(UProperty, m);
     INSTALL_CONSTANTS_TYPE(USetSpanCondition, m);
 
     REGISTER_TYPE(UnicodeFunctor, m);
@@ -1395,103 +1393,6 @@ void _init_unicodeset(PyObject *m)
     INSTALL_ENUM(UMatchDegree, "PARTIAL_MATCH", U_PARTIAL_MATCH);
     INSTALL_ENUM(UMatchDegree, "MATCH", U_MATCH);
 
-    INSTALL_ENUM(UProperty, "ALPHABETIC", UCHAR_ALPHABETIC);
-    INSTALL_ENUM(UProperty, "BINARY_START", UCHAR_BINARY_START);
-    INSTALL_ENUM(UProperty, "ASCII_HEX_DIGIT", UCHAR_ASCII_HEX_DIGIT);
-    INSTALL_ENUM(UProperty, "BIDI_CONTROL", UCHAR_BIDI_CONTROL);
-    INSTALL_ENUM(UProperty, "BIDI_MIRRORED", UCHAR_BIDI_MIRRORED);
-    INSTALL_ENUM(UProperty, "DASH", UCHAR_DASH);
-    INSTALL_ENUM(UProperty, "DEFAULT_IGNORABLE_CODE_POINT", UCHAR_DEFAULT_IGNORABLE_CODE_POINT);
-    INSTALL_ENUM(UProperty, "DEPRECATED", UCHAR_DEPRECATED);
-    INSTALL_ENUM(UProperty, "DIACRITIC", UCHAR_DIACRITIC);
-    INSTALL_ENUM(UProperty, "EXTENDER", UCHAR_EXTENDER);
-    INSTALL_ENUM(UProperty, "FULL_COMPOSITION_EXCLUSION", UCHAR_FULL_COMPOSITION_EXCLUSION);
-    INSTALL_ENUM(UProperty, "GRAPHEME_BASE", UCHAR_GRAPHEME_BASE);
-    INSTALL_ENUM(UProperty, "GRAPHEME_EXTEND", UCHAR_GRAPHEME_EXTEND);
-    INSTALL_ENUM(UProperty, "GRAPHEME_LINK", UCHAR_GRAPHEME_LINK);
-    INSTALL_ENUM(UProperty, "HEX_DIGIT", UCHAR_HEX_DIGIT);
-    INSTALL_ENUM(UProperty, "HYPHEN", UCHAR_HYPHEN);
-    INSTALL_ENUM(UProperty, "ID_CONTINUE", UCHAR_ID_CONTINUE);
-    INSTALL_ENUM(UProperty, "ID_START", UCHAR_ID_START);
-    INSTALL_ENUM(UProperty, "IDEOGRAPHIC", UCHAR_IDEOGRAPHIC);
-    INSTALL_ENUM(UProperty, "IDS_BINARY_OPERATOR", UCHAR_IDS_BINARY_OPERATOR);
-    INSTALL_ENUM(UProperty, "IDS_TRINARY_OPERATOR", UCHAR_IDS_TRINARY_OPERATOR);
-    INSTALL_ENUM(UProperty, "JOIN_CONTROL", UCHAR_JOIN_CONTROL);
-    INSTALL_ENUM(UProperty, "LOGICAL_ORDER_EXCEPTION", UCHAR_LOGICAL_ORDER_EXCEPTION);
-    INSTALL_ENUM(UProperty, "LOWERCASE", UCHAR_LOWERCASE);
-    INSTALL_ENUM(UProperty, "MATH", UCHAR_MATH);
-    INSTALL_ENUM(UProperty, "NONCHARACTER_CODE_POINT", UCHAR_NONCHARACTER_CODE_POINT);
-    INSTALL_ENUM(UProperty, "QUOTATION_MARK", UCHAR_QUOTATION_MARK);
-    INSTALL_ENUM(UProperty, "RADICAL", UCHAR_RADICAL);
-    INSTALL_ENUM(UProperty, "SOFT_DOTTED", UCHAR_SOFT_DOTTED);
-    INSTALL_ENUM(UProperty, "TERMINAL_PUNCTUATION", UCHAR_TERMINAL_PUNCTUATION);
-    INSTALL_ENUM(UProperty, "UNIFIED_IDEOGRAPH", UCHAR_UNIFIED_IDEOGRAPH);
-    INSTALL_ENUM(UProperty, "UPPERCASE", UCHAR_UPPERCASE);
-    INSTALL_ENUM(UProperty, "WHITE_SPACE", UCHAR_WHITE_SPACE);
-    INSTALL_ENUM(UProperty, "XID_CONTINUE", UCHAR_XID_CONTINUE);
-    INSTALL_ENUM(UProperty, "XID_START", UCHAR_XID_START);
-    INSTALL_ENUM(UProperty, "CASE_SENSITIVE", UCHAR_CASE_SENSITIVE);
-    INSTALL_ENUM(UProperty, "S_TERM", UCHAR_S_TERM);
-    INSTALL_ENUM(UProperty, "VARIATION_SELECTOR", UCHAR_VARIATION_SELECTOR);
-    INSTALL_ENUM(UProperty, "NFD_INERT", UCHAR_NFD_INERT);
-    INSTALL_ENUM(UProperty, "NFKD_INERT", UCHAR_NFKD_INERT);
-    INSTALL_ENUM(UProperty, "NFC_INERT", UCHAR_NFC_INERT);
-    INSTALL_ENUM(UProperty, "NFKC_INERT", UCHAR_NFKC_INERT);
-    INSTALL_ENUM(UProperty, "SEGMENT_STARTER", UCHAR_SEGMENT_STARTER);
-    INSTALL_ENUM(UProperty, "PATTERN_SYNTAX", UCHAR_PATTERN_SYNTAX);
-    INSTALL_ENUM(UProperty, "PATTERN_WHITE_SPACE", UCHAR_PATTERN_WHITE_SPACE);
-    INSTALL_ENUM(UProperty, "POSIX_ALNUM", UCHAR_POSIX_ALNUM);
-    INSTALL_ENUM(UProperty, "POSIX_BLANK", UCHAR_POSIX_BLANK);
-    INSTALL_ENUM(UProperty, "POSIX_GRAPH", UCHAR_POSIX_GRAPH);
-    INSTALL_ENUM(UProperty, "POSIX_PRINT", UCHAR_POSIX_PRINT);
-    INSTALL_ENUM(UProperty, "POSIX_XDIGIT", UCHAR_POSIX_XDIGIT);
-    INSTALL_ENUM(UProperty, "BINARY_LIMIT", UCHAR_BINARY_LIMIT);
-    INSTALL_ENUM(UProperty, "BIDI_CLASS", UCHAR_BIDI_CLASS);
-    INSTALL_ENUM(UProperty, "INT_START", UCHAR_INT_START);
-    INSTALL_ENUM(UProperty, "BLOCK", UCHAR_BLOCK);
-    INSTALL_ENUM(UProperty, "CANONICAL_COMBINING_CLASS", UCHAR_CANONICAL_COMBINING_CLASS);
-    INSTALL_ENUM(UProperty, "DECOMPOSITION_TYPE", UCHAR_DECOMPOSITION_TYPE);
-    INSTALL_ENUM(UProperty, "EAST_ASIAN_WIDTH", UCHAR_EAST_ASIAN_WIDTH);
-    INSTALL_ENUM(UProperty, "GENERAL_CATEGORY", UCHAR_GENERAL_CATEGORY);
-    INSTALL_ENUM(UProperty, "JOINING_GROUP", UCHAR_JOINING_GROUP);
-    INSTALL_ENUM(UProperty, "JOINING_TYPE", UCHAR_JOINING_TYPE);
-    INSTALL_ENUM(UProperty, "LINE_BREAK", UCHAR_LINE_BREAK);
-    INSTALL_ENUM(UProperty, "NUMERIC_TYPE", UCHAR_NUMERIC_TYPE);
-    INSTALL_ENUM(UProperty, "SCRIPT", UCHAR_SCRIPT);
-    INSTALL_ENUM(UProperty, "HANGUL_SYLLABLE_TYPE", UCHAR_HANGUL_SYLLABLE_TYPE);
-    INSTALL_ENUM(UProperty, "NFD_QUICK_CHECK", UCHAR_NFD_QUICK_CHECK);
-    INSTALL_ENUM(UProperty, "NFKD_QUICK_CHECK", UCHAR_NFKD_QUICK_CHECK);
-    INSTALL_ENUM(UProperty, "NFC_QUICK_CHECK", UCHAR_NFC_QUICK_CHECK);
-    INSTALL_ENUM(UProperty, "NFKC_QUICK_CHECK", UCHAR_NFKC_QUICK_CHECK);
-    INSTALL_ENUM(UProperty, "LEAD_CANONICAL_COMBINING_CLASS", UCHAR_LEAD_CANONICAL_COMBINING_CLASS);
-    INSTALL_ENUM(UProperty, "TRAIL_CANONICAL_COMBINING_CLASS", UCHAR_TRAIL_CANONICAL_COMBINING_CLASS);
-    INSTALL_ENUM(UProperty, "GRAPHEME_CLUSTER_BREAK", UCHAR_GRAPHEME_CLUSTER_BREAK);
-    INSTALL_ENUM(UProperty, "SENTENCE_BREAK", UCHAR_SENTENCE_BREAK);
-    INSTALL_ENUM(UProperty, "WORD_BREAK", UCHAR_WORD_BREAK);
-    INSTALL_ENUM(UProperty, "INT_LIMIT", UCHAR_INT_LIMIT);
-    INSTALL_ENUM(UProperty, "GENERAL_CATEGORY_MASK", UCHAR_GENERAL_CATEGORY_MASK);
-    INSTALL_ENUM(UProperty, "MASK_START", UCHAR_MASK_START);
-    INSTALL_ENUM(UProperty, "MASK_LIMIT", UCHAR_MASK_LIMIT);
-    INSTALL_ENUM(UProperty, "NUMERIC_VALUE", UCHAR_NUMERIC_VALUE);
-    INSTALL_ENUM(UProperty, "DOUBLE_START", UCHAR_DOUBLE_START);
-    INSTALL_ENUM(UProperty, "DOUBLE_LIMIT", UCHAR_DOUBLE_LIMIT);
-    INSTALL_ENUM(UProperty, "AGE", UCHAR_AGE);
-    INSTALL_ENUM(UProperty, "STRING_START", UCHAR_STRING_START);
-    INSTALL_ENUM(UProperty, "BIDI_MIRRORING_GLYPH", UCHAR_BIDI_MIRRORING_GLYPH);
-    INSTALL_ENUM(UProperty, "CASE_FOLDING", UCHAR_CASE_FOLDING);
-    INSTALL_ENUM(UProperty, "ISO_COMMENT", UCHAR_ISO_COMMENT);
-    INSTALL_ENUM(UProperty, "LOWERCASE_MAPPING", UCHAR_LOWERCASE_MAPPING);
-    INSTALL_ENUM(UProperty, "NAME", UCHAR_NAME);
-    INSTALL_ENUM(UProperty, "SIMPLE_CASE_FOLDING", UCHAR_SIMPLE_CASE_FOLDING);
-    INSTALL_ENUM(UProperty, "SIMPLE_LOWERCASE_MAPPING", UCHAR_SIMPLE_LOWERCASE_MAPPING);
-    INSTALL_ENUM(UProperty, "SIMPLE_TITLECASE_MAPPING", UCHAR_SIMPLE_TITLECASE_MAPPING);
-    INSTALL_ENUM(UProperty, "SIMPLE_UPPERCASE_MAPPING", UCHAR_SIMPLE_UPPERCASE_MAPPING);
-    INSTALL_ENUM(UProperty, "TITLECASE_MAPPING", UCHAR_TITLECASE_MAPPING);
-    INSTALL_ENUM(UProperty, "UNICODE_1_NAME", UCHAR_UNICODE_1_NAME);
-    INSTALL_ENUM(UProperty, "UPPERCASE_MAPPING", UCHAR_UPPERCASE_MAPPING);
-    INSTALL_ENUM(UProperty, "STRING_LIMIT", UCHAR_STRING_LIMIT);
-    INSTALL_ENUM(UProperty, "INVALID_CODE", UCHAR_INVALID_CODE);
-
     INSTALL_ENUM(USetSpanCondition, "SPAN_NOT_CONTAINED", USET_SPAN_NOT_CONTAINED);
     INSTALL_ENUM(USetSpanCondition, "SPAN_CONTAINED", USET_SPAN_CONTAINED);
     INSTALL_ENUM(USetSpanCondition, "SPAN_SIMPLE", USET_SPAN_SIMPLE);
